diff --git a/spring-batch-execution/src/main/java/org/springframework/batch/execution/bootstrap/support/CommandLineJobRunner.java b/spring-batch-execution/src/main/java/org/springframework/batch/execution/bootstrap/support/CommandLineJobRunner.java
index 9536e39b4..abb738329 100644
--- a/spring-batch-execution/src/main/java/org/springframework/batch/execution/bootstrap/support/CommandLineJobRunner.java
+++ b/spring-batch-execution/src/main/java/org/springframework/batch/execution/bootstrap/support/CommandLineJobRunner.java
@@ -27,7 +27,7 @@ import org.springframework.batch.core.repository.JobLocator;
import org.springframework.batch.core.runtime.ExitStatusExceptionClassifier;
import org.springframework.batch.core.runtime.JobParametersFactory;
import org.springframework.batch.execution.launch.JobLauncher;
-import org.springframework.batch.execution.step.simple.SimpleExitStatusExceptionClassifier;
+import org.springframework.batch.execution.step.support.SimpleExitStatusExceptionClassifier;
import org.springframework.beans.factory.BeanDefinitionStoreException;
import org.springframework.beans.factory.config.AutowireCapableBeanFactory;
import org.springframework.context.ApplicationContext;
diff --git a/spring-batch-execution/src/main/java/org/springframework/batch/execution/job/simple/SimpleJob.java b/spring-batch-execution/src/main/java/org/springframework/batch/execution/job/simple/SimpleJob.java
index 5ede85628..bdd7bd84f 100644
--- a/spring-batch-execution/src/main/java/org/springframework/batch/execution/job/simple/SimpleJob.java
+++ b/spring-batch-execution/src/main/java/org/springframework/batch/execution/job/simple/SimpleJob.java
@@ -30,7 +30,7 @@ import org.springframework.batch.core.domain.Step;
import org.springframework.batch.core.domain.StepExecution;
import org.springframework.batch.core.repository.JobRepository;
import org.springframework.batch.core.runtime.ExitStatusExceptionClassifier;
-import org.springframework.batch.execution.step.simple.SimpleExitStatusExceptionClassifier;
+import org.springframework.batch.execution.step.support.SimpleExitStatusExceptionClassifier;
import org.springframework.batch.io.exception.BatchCriticalException;
import org.springframework.batch.repeat.ExitStatus;
diff --git a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/AbstractStep.java b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/AbstractStep.java
index 240877565..08c349a81 100644
--- a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/AbstractStep.java
+++ b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/AbstractStep.java
@@ -22,8 +22,8 @@ import org.springframework.batch.core.domain.Step;
import org.springframework.batch.core.domain.StepExecution;
import org.springframework.batch.core.domain.StepSupport;
import org.springframework.batch.core.repository.JobRepository;
-import org.springframework.batch.execution.step.simple.DefaultItemFailureHandler;
-import org.springframework.batch.execution.step.simple.NeverSkipItemSkipPolicy;
+import org.springframework.batch.execution.step.support.DefaultItemFailureHandler;
+import org.springframework.batch.execution.step.support.NeverSkipItemSkipPolicy;
import org.springframework.batch.io.exception.BatchCriticalException;
import org.springframework.batch.item.ItemReader;
import org.springframework.batch.item.ItemWriter;
diff --git a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/ChunkedStep.java b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/ChunkedStep.java
index 613f4df50..006a9f709 100644
--- a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/ChunkedStep.java
+++ b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/ChunkedStep.java
@@ -40,12 +40,12 @@ import org.springframework.batch.execution.scope.SimpleStepContext;
import org.springframework.batch.execution.scope.StepContext;
import org.springframework.batch.execution.scope.StepScope;
import org.springframework.batch.execution.scope.StepSynchronizationManager;
-import org.springframework.batch.execution.step.simple.DefaultItemFailureHandler;
-import org.springframework.batch.execution.step.simple.ItemChunker;
-import org.springframework.batch.execution.step.simple.ItemDechunker;
-import org.springframework.batch.execution.step.simple.SimpleExitStatusExceptionClassifier;
-import org.springframework.batch.execution.step.simple.StepInterruptionPolicy;
-import org.springframework.batch.execution.step.simple.ThreadStepInterruptionPolicy;
+import org.springframework.batch.execution.step.support.DefaultItemFailureHandler;
+import org.springframework.batch.execution.step.support.ItemChunker;
+import org.springframework.batch.execution.step.support.ItemDechunker;
+import org.springframework.batch.execution.step.support.SimpleExitStatusExceptionClassifier;
+import org.springframework.batch.execution.step.support.StepInterruptionPolicy;
+import org.springframework.batch.execution.step.support.ThreadStepInterruptionPolicy;
import org.springframework.batch.io.exception.BatchCriticalException;
import org.springframework.batch.io.exception.WriteFailureException;
import org.springframework.batch.item.ExecutionContext;
diff --git a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/ItemOrientedStep.java b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/ItemOrientedStep.java
index 2b9fbbcf7..593882e40 100644
--- a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/ItemOrientedStep.java
+++ b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/ItemOrientedStep.java
@@ -31,9 +31,9 @@ import org.springframework.batch.execution.scope.SimpleStepContext;
import org.springframework.batch.execution.scope.StepContext;
import org.springframework.batch.execution.scope.StepScope;
import org.springframework.batch.execution.scope.StepSynchronizationManager;
-import org.springframework.batch.execution.step.simple.SimpleExitStatusExceptionClassifier;
-import org.springframework.batch.execution.step.simple.StepInterruptionPolicy;
-import org.springframework.batch.execution.step.simple.ThreadStepInterruptionPolicy;
+import org.springframework.batch.execution.step.support.SimpleExitStatusExceptionClassifier;
+import org.springframework.batch.execution.step.support.StepInterruptionPolicy;
+import org.springframework.batch.execution.step.support.ThreadStepInterruptionPolicy;
import org.springframework.batch.io.Skippable;
import org.springframework.batch.io.exception.BatchCriticalException;
import org.springframework.batch.item.ExecutionContext;
diff --git a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/AlwaysSkipItemSkipPolicy.java b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/AlwaysSkipItemSkipPolicy.java
similarity index 94%
rename from spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/AlwaysSkipItemSkipPolicy.java
rename to spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/AlwaysSkipItemSkipPolicy.java
index 6f4665ef2..6d8cb3379 100644
--- a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/AlwaysSkipItemSkipPolicy.java
+++ b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/AlwaysSkipItemSkipPolicy.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package org.springframework.batch.execution.step.simple;
+package org.springframework.batch.execution.step.support;
import org.springframework.batch.core.domain.ItemSkipPolicy;
import org.springframework.batch.core.domain.StepContribution;
diff --git a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/DefaultItemFailureHandler.java b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/DefaultItemFailureHandler.java
similarity index 96%
rename from spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/DefaultItemFailureHandler.java
rename to spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/DefaultItemFailureHandler.java
index 1a0a5a532..34780c3ae 100644
--- a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/DefaultItemFailureHandler.java
+++ b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/DefaultItemFailureHandler.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package org.springframework.batch.execution.step.simple;
+package org.springframework.batch.execution.step.support;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
diff --git a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/ItemChunker.java b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/ItemChunker.java
similarity index 98%
rename from spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/ItemChunker.java
rename to spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/ItemChunker.java
index 2a8cafa44..471b41c63 100644
--- a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/ItemChunker.java
+++ b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/ItemChunker.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package org.springframework.batch.execution.step.simple;
+package org.springframework.batch.execution.step.support;
import java.util.ArrayList;
import java.util.List;
diff --git a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/ItemDechunker.java b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/ItemDechunker.java
similarity index 98%
rename from spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/ItemDechunker.java
rename to spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/ItemDechunker.java
index c7156a0eb..486bb11e9 100644
--- a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/ItemDechunker.java
+++ b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/ItemDechunker.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package org.springframework.batch.execution.step.simple;
+package org.springframework.batch.execution.step.support;
import java.util.ArrayList;
import java.util.Iterator;
diff --git a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/LimitCheckingItemSkipPolicy.java b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/LimitCheckingItemSkipPolicy.java
similarity index 98%
rename from spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/LimitCheckingItemSkipPolicy.java
rename to spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/LimitCheckingItemSkipPolicy.java
index 526f40d39..2039a0dca 100644
--- a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/LimitCheckingItemSkipPolicy.java
+++ b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/LimitCheckingItemSkipPolicy.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package org.springframework.batch.execution.step.simple;
+package org.springframework.batch.execution.step.support;
import java.io.FileNotFoundException;
import java.util.ArrayList;
diff --git a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/NeverSkipItemSkipPolicy.java b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/NeverSkipItemSkipPolicy.java
similarity index 94%
rename from spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/NeverSkipItemSkipPolicy.java
rename to spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/NeverSkipItemSkipPolicy.java
index e4ac45dd2..695515145 100644
--- a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/NeverSkipItemSkipPolicy.java
+++ b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/NeverSkipItemSkipPolicy.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package org.springframework.batch.execution.step.simple;
+package org.springframework.batch.execution.step.support;
import org.springframework.batch.core.domain.ItemSkipPolicy;
import org.springframework.batch.core.domain.StepContribution;
diff --git a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/RepeatOperationsHolder.java b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/RepeatOperationsHolder.java
similarity index 93%
rename from spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/RepeatOperationsHolder.java
rename to spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/RepeatOperationsHolder.java
index 3799fdce7..2193fa194 100644
--- a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/RepeatOperationsHolder.java
+++ b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/RepeatOperationsHolder.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package org.springframework.batch.execution.step.simple;
+package org.springframework.batch.execution.step.support;
import org.springframework.batch.core.domain.Step;
import org.springframework.batch.repeat.RepeatOperations;
diff --git a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/RepeatOperationsStep.java b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/RepeatOperationsStep.java
similarity index 97%
rename from spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/RepeatOperationsStep.java
rename to spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/RepeatOperationsStep.java
index b324216bc..ac3ea34ef 100644
--- a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/RepeatOperationsStep.java
+++ b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/RepeatOperationsStep.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.batch.execution.step.simple;
+package org.springframework.batch.execution.step.support;
import org.springframework.batch.core.domain.JobInterruptedException;
import org.springframework.batch.core.domain.Step;
diff --git a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/SimpleExitStatusExceptionClassifier.java b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/SimpleExitStatusExceptionClassifier.java
similarity index 94%
rename from spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/SimpleExitStatusExceptionClassifier.java
rename to spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/SimpleExitStatusExceptionClassifier.java
index 8ef14e342..9ec3e0c48 100644
--- a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/SimpleExitStatusExceptionClassifier.java
+++ b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/SimpleExitStatusExceptionClassifier.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package org.springframework.batch.execution.step.simple;
+package org.springframework.batch.execution.step.support;
import java.io.PrintWriter;
import java.io.StringWriter;
diff --git a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/SkipLimitExceededException.java b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/SkipLimitExceededException.java
similarity index 95%
rename from spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/SkipLimitExceededException.java
rename to spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/SkipLimitExceededException.java
index 3e31a62ec..3891b9eaa 100644
--- a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/SkipLimitExceededException.java
+++ b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/SkipLimitExceededException.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package org.springframework.batch.execution.step.simple;
+package org.springframework.batch.execution.step.support;
import org.springframework.batch.io.exception.BatchCriticalException;
diff --git a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/StepInterruptionPolicy.java b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/StepInterruptionPolicy.java
similarity index 95%
rename from spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/StepInterruptionPolicy.java
rename to spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/StepInterruptionPolicy.java
index f1142e856..86726f390 100644
--- a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/StepInterruptionPolicy.java
+++ b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/StepInterruptionPolicy.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.batch.execution.step.simple;
+package org.springframework.batch.execution.step.support;
import org.springframework.batch.core.domain.JobInterruptedException;
import org.springframework.batch.core.domain.Step;
diff --git a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/ThreadStepInterruptionPolicy.java b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/ThreadStepInterruptionPolicy.java
similarity index 96%
rename from spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/ThreadStepInterruptionPolicy.java
rename to spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/ThreadStepInterruptionPolicy.java
index 03fe801ed..9875465b5 100644
--- a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/ThreadStepInterruptionPolicy.java
+++ b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/ThreadStepInterruptionPolicy.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.batch.execution.step.simple;
+package org.springframework.batch.execution.step.support;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
diff --git a/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/package.html b/spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/package.html
similarity index 100%
rename from spring-batch-execution/src/main/java/org/springframework/batch/execution/step/simple/package.html
rename to spring-batch-execution/src/main/java/org/springframework/batch/execution/step/support/package.html
diff --git a/spring-batch-execution/src/test/java/org/springframework/batch/execution/launch/SimpleJobTests.java b/spring-batch-execution/src/test/java/org/springframework/batch/execution/launch/SimpleJobTests.java
index ea9f6e204..03f2b9e90 100644
--- a/spring-batch-execution/src/test/java/org/springframework/batch/execution/launch/SimpleJobTests.java
+++ b/spring-batch-execution/src/test/java/org/springframework/batch/execution/launch/SimpleJobTests.java
@@ -33,7 +33,7 @@ import org.springframework.batch.execution.repository.SimpleJobRepository;
import org.springframework.batch.execution.repository.dao.MapJobDao;
import org.springframework.batch.execution.repository.dao.MapStepDao;
import org.springframework.batch.execution.step.AbstractStep;
-import org.springframework.batch.execution.step.simple.RepeatOperationsStep;
+import org.springframework.batch.execution.step.support.RepeatOperationsStep;
import org.springframework.batch.item.ItemReader;
import org.springframework.batch.item.ItemRecoverer;
import org.springframework.batch.item.ItemWriter;
diff --git a/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/ChunkedStepTests.java b/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/ChunkedStepTests.java
index c94b20a91..5c0511afa 100644
--- a/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/ChunkedStepTests.java
+++ b/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/ChunkedStepTests.java
@@ -31,9 +31,9 @@ import org.springframework.batch.core.domain.StepExecution;
import org.springframework.batch.core.repository.JobRepository;
import org.springframework.batch.execution.scope.StepScope;
import org.springframework.batch.execution.scope.StepSynchronizationManager;
-import org.springframework.batch.execution.step.simple.ItemChunker;
-import org.springframework.batch.execution.step.simple.ItemDechunker;
-import org.springframework.batch.execution.step.simple.JobRepositorySupport;
+import org.springframework.batch.execution.step.support.ItemChunker;
+import org.springframework.batch.execution.step.support.ItemDechunker;
+import org.springframework.batch.execution.step.support.JobRepositorySupport;
import org.springframework.batch.item.ExecutionContext;
import org.springframework.batch.item.ItemReader;
import org.springframework.batch.item.ItemWriter;
diff --git a/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/ItemOrientedStepTests.java b/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/ItemOrientedStepTests.java
index acf4ae9fc..a88f90037 100644
--- a/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/ItemOrientedStepTests.java
+++ b/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/ItemOrientedStepTests.java
@@ -38,8 +38,8 @@ import org.springframework.batch.execution.repository.dao.MapStepDao;
import org.springframework.batch.execution.scope.StepScope;
import org.springframework.batch.execution.scope.StepSynchronizationManager;
import org.springframework.batch.execution.step.ItemOrientedStep;
-import org.springframework.batch.execution.step.simple.JobRepositorySupport;
-import org.springframework.batch.execution.step.simple.StepInterruptionPolicy;
+import org.springframework.batch.execution.step.support.JobRepositorySupport;
+import org.springframework.batch.execution.step.support.StepInterruptionPolicy;
import org.springframework.batch.io.exception.BatchCriticalException;
import org.springframework.batch.item.ExecutionContext;
import org.springframework.batch.item.ItemReader;
diff --git a/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/TaskletStepTests.java b/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/TaskletStepTests.java
index 20f89f80c..bbb1d6fb4 100644
--- a/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/TaskletStepTests.java
+++ b/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/TaskletStepTests.java
@@ -12,7 +12,7 @@ import org.springframework.batch.core.domain.JobParameters;
import org.springframework.batch.core.domain.StepExecution;
import org.springframework.batch.core.tasklet.Tasklet;
import org.springframework.batch.execution.step.TaskletStep;
-import org.springframework.batch.execution.step.simple.JobRepositorySupport;
+import org.springframework.batch.execution.step.support.JobRepositorySupport;
import org.springframework.batch.io.exception.BatchCriticalException;
import org.springframework.batch.repeat.ExitStatus;
import org.springframework.batch.repeat.RepeatContext;
diff --git a/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/simple/ItemChunkerTests.java b/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/support/ItemChunkerTests.java
similarity index 96%
rename from spring-batch-execution/src/test/java/org/springframework/batch/execution/step/simple/ItemChunkerTests.java
rename to spring-batch-execution/src/test/java/org/springframework/batch/execution/step/support/ItemChunkerTests.java
index d056ef8af..634d8e056 100644
--- a/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/simple/ItemChunkerTests.java
+++ b/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/support/ItemChunkerTests.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package org.springframework.batch.execution.step.simple;
+package org.springframework.batch.execution.step.support;
import junit.framework.TestCase;
@@ -21,6 +21,7 @@ import org.springframework.batch.core.domain.ChunkingResult;
import org.springframework.batch.core.domain.ItemSkipPolicy;
import org.springframework.batch.core.domain.StepContribution;
import org.springframework.batch.core.domain.StepExecution;
+import org.springframework.batch.execution.step.support.ItemChunker;
public class ItemChunkerTests extends TestCase {
diff --git a/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/simple/ItemDechunkerTests.java b/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/support/ItemDechunkerTests.java
similarity index 93%
rename from spring-batch-execution/src/test/java/org/springframework/batch/execution/step/simple/ItemDechunkerTests.java
rename to spring-batch-execution/src/test/java/org/springframework/batch/execution/step/support/ItemDechunkerTests.java
index bdd6ea8de..da2711232 100644
--- a/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/simple/ItemDechunkerTests.java
+++ b/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/support/ItemDechunkerTests.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package org.springframework.batch.execution.step.simple;
+package org.springframework.batch.execution.step.support;
import java.util.ArrayList;
import java.util.List;
@@ -23,6 +23,8 @@ import org.springframework.batch.core.domain.Chunk;
import org.springframework.batch.core.domain.DechunkingResult;
import org.springframework.batch.core.domain.StepContribution;
import org.springframework.batch.core.domain.StepExecution;
+import org.springframework.batch.execution.step.support.AlwaysSkipItemSkipPolicy;
+import org.springframework.batch.execution.step.support.ItemDechunker;
import org.springframework.batch.io.exception.WriteFailureException;
import org.springframework.batch.item.ItemWriter;
diff --git a/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/simple/JobRepositorySupport.java b/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/support/JobRepositorySupport.java
similarity index 94%
rename from spring-batch-execution/src/test/java/org/springframework/batch/execution/step/simple/JobRepositorySupport.java
rename to spring-batch-execution/src/test/java/org/springframework/batch/execution/step/support/JobRepositorySupport.java
index 54981fdf3..87a6b6263 100644
--- a/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/simple/JobRepositorySupport.java
+++ b/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/support/JobRepositorySupport.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package org.springframework.batch.execution.step.simple;
+package org.springframework.batch.execution.step.support;
import org.springframework.batch.core.domain.Job;
import org.springframework.batch.core.domain.JobExecution;
diff --git a/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/simple/MockItemReader.java b/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/support/MockItemReader.java
similarity index 95%
rename from spring-batch-execution/src/test/java/org/springframework/batch/execution/step/simple/MockItemReader.java
rename to spring-batch-execution/src/test/java/org/springframework/batch/execution/step/support/MockItemReader.java
index 6cfd958a1..731cb5e9e 100644
--- a/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/simple/MockItemReader.java
+++ b/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/support/MockItemReader.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package org.springframework.batch.execution.step.simple;
+package org.springframework.batch.execution.step.support;
import org.springframework.batch.item.ItemReader;
diff --git a/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/simple/SimpleExitStatusExceptionClassifierTests.java b/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/support/SimpleExitStatusExceptionClassifierTests.java
similarity index 92%
rename from spring-batch-execution/src/test/java/org/springframework/batch/execution/step/simple/SimpleExitStatusExceptionClassifierTests.java
rename to spring-batch-execution/src/test/java/org/springframework/batch/execution/step/support/SimpleExitStatusExceptionClassifierTests.java
index 5e6159b81..b8a4ff5e4 100644
--- a/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/simple/SimpleExitStatusExceptionClassifierTests.java
+++ b/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/support/SimpleExitStatusExceptionClassifierTests.java
@@ -13,11 +13,12 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package org.springframework.batch.execution.step.simple;
+package org.springframework.batch.execution.step.support;
import org.springframework.batch.core.domain.JobInterruptedException;
import org.springframework.batch.core.runtime.ExitStatusExceptionClassifier;
+import org.springframework.batch.execution.step.support.SimpleExitStatusExceptionClassifier;
import org.springframework.batch.repeat.ExitStatus;
import junit.framework.TestCase;
diff --git a/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/simple/SkipLimitReadFailurePolicyTests.java b/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/support/SkipLimitReadFailurePolicyTests.java
similarity index 90%
rename from spring-batch-execution/src/test/java/org/springframework/batch/execution/step/simple/SkipLimitReadFailurePolicyTests.java
rename to spring-batch-execution/src/test/java/org/springframework/batch/execution/step/support/SkipLimitReadFailurePolicyTests.java
index 6d00c0485..70b4ee442 100644
--- a/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/simple/SkipLimitReadFailurePolicyTests.java
+++ b/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/support/SkipLimitReadFailurePolicyTests.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package org.springframework.batch.execution.step.simple;
+package org.springframework.batch.execution.step.support;
import java.io.FileNotFoundException;
import java.util.ArrayList;
@@ -21,6 +21,8 @@ import java.util.List;
import org.springframework.batch.core.domain.StepContribution;
import org.springframework.batch.core.domain.StepExecution;
+import org.springframework.batch.execution.step.support.LimitCheckingItemSkipPolicy;
+import org.springframework.batch.execution.step.support.SkipLimitExceededException;
import org.springframework.batch.io.exception.FlatFileParsingException;
import junit.framework.TestCase;
diff --git a/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/simple/StepExecutorInterruptionTests.java b/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/support/StepExecutorInterruptionTests.java
similarity index 97%
rename from spring-batch-execution/src/test/java/org/springframework/batch/execution/step/simple/StepExecutorInterruptionTests.java
rename to spring-batch-execution/src/test/java/org/springframework/batch/execution/step/support/StepExecutorInterruptionTests.java
index 93a9f4dc9..3261d8d7b 100644
--- a/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/simple/StepExecutorInterruptionTests.java
+++ b/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/support/StepExecutorInterruptionTests.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.batch.execution.step.simple;
+package org.springframework.batch.execution.step.support;
import java.util.List;
@@ -34,6 +34,7 @@ import org.springframework.batch.execution.repository.dao.JobInstanceDao;
import org.springframework.batch.execution.repository.dao.MapJobDao;
import org.springframework.batch.execution.repository.dao.MapStepDao;
import org.springframework.batch.execution.repository.dao.StepExecutionDao;
+import org.springframework.batch.execution.step.support.RepeatOperationsStep;
import org.springframework.batch.item.ItemReader;
import org.springframework.batch.item.ItemWriter;
import org.springframework.batch.item.reader.ItemReaderAdapter;
diff --git a/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/simple/ThreadStepInterruptionPolicyTests.java b/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/support/ThreadStepInterruptionPolicyTests.java
similarity index 87%
rename from spring-batch-execution/src/test/java/org/springframework/batch/execution/step/simple/ThreadStepInterruptionPolicyTests.java
rename to spring-batch-execution/src/test/java/org/springframework/batch/execution/step/support/ThreadStepInterruptionPolicyTests.java
index 6d4a4b0d9..7cdbca232 100644
--- a/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/simple/ThreadStepInterruptionPolicyTests.java
+++ b/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/support/ThreadStepInterruptionPolicyTests.java
@@ -13,11 +13,13 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package org.springframework.batch.execution.step.simple;
+package org.springframework.batch.execution.step.support;
import junit.framework.TestCase;
import org.springframework.batch.core.domain.JobInterruptedException;
+import org.springframework.batch.execution.step.support.ThreadStepInterruptionPolicy;
+import org.springframework.batch.execution.step.support.org;
import org.springframework.batch.repeat.RepeatContext;
import org.springframework.batch.repeat.context.RepeatContextSupport;
diff --git a/spring-batch-execution/src/test/resources/org/springframework/batch/execution/bootstrap/support/job.xml b/spring-batch-execution/src/test/resources/org/springframework/batch/execution/bootstrap/support/job.xml
index 2723a12ee..b27b10966 100644
--- a/spring-batch-execution/src/test/resources/org/springframework/batch/execution/bootstrap/support/job.xml
+++ b/spring-batch-execution/src/test/resources/org/springframework/batch/execution/bootstrap/support/job.xml
@@ -25,7 +25,7 @@
class="org.springframework.batch.execution.launch.EmptyItemWriter" />
-
+
diff --git a/spring-batch-execution/src/test/resources/org/springframework/batch/execution/configuration/test-context.xml b/spring-batch-execution/src/test/resources/org/springframework/batch/execution/configuration/test-context.xml
index f7cc96f16..4cb078c9a 100644
--- a/spring-batch-execution/src/test/resources/org/springframework/batch/execution/configuration/test-context.xml
+++ b/spring-batch-execution/src/test/resources/org/springframework/batch/execution/configuration/test-context.xml
@@ -40,7 +40,7 @@
class="org.springframework.batch.execution.launch.EmptyItemWriter" />
+ class="org.springframework.batch.execution.step.support.JobRepositorySupport" />
diff --git a/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/simple/RepeatOperationsStepTests.java b/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/support/RepeatOperationsStepTests.java
similarity index 93%
rename from spring-batch-execution/src/test/java/org/springframework/batch/execution/step/simple/RepeatOperationsStepTests.java
rename to spring-batch-execution/src/test/java/org/springframework/batch/execution/step/support/RepeatOperationsStepTests.java
index 5d96f89ef..e78bed213 100644
--- a/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/simple/RepeatOperationsStepTests.java
+++ b/spring-batch-execution/src/test/java/org/springframework/batch/execution/step/support/RepeatOperationsStepTests.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package org.springframework.batch.execution.step.simple;
+package org.springframework.batch.execution.step.support;
import java.util.ArrayList;
import java.util.List;
@@ -25,6 +25,7 @@ import org.springframework.batch.core.domain.JobInstance;
import org.springframework.batch.core.domain.JobParameters;
import org.springframework.batch.core.domain.StepExecution;
import org.springframework.batch.execution.step.ItemOrientedStep;
+import org.springframework.batch.execution.step.support.RepeatOperationsStep;
import org.springframework.batch.item.ItemReader;
import org.springframework.batch.item.ItemWriter;
import org.springframework.batch.item.reader.ItemReaderAdapter;
@@ -51,7 +52,7 @@ public class RepeatOperationsStepTests extends TestCase {
}
/**
* Test method for {@link org.springframework.batch.execution.step.simple.RepeatOperationsStep#getChunkOperations()}.
*/
public void testSetChunkOperations() {
assertNull(repeatStep.getChunkOperations());
@@ -62,7 +63,7 @@ public class RepeatOperationsStepTests extends TestCase {
}
/**
* Test method for {@link org.springframework.batch.execution.step.simple.RepeatOperationsStep#getChunkOperations()}.
*/
public void testSetStepOperations() {
assertNull(repeatStep.getChunkOperations());
@@ -51,7 +52,7 @@ public class RepeatOperationsStepTests extends TestCase {
}
/**
- * Test method for {@link org.springframework.batch.execution.step.simple.RepeatOperationsStep#getChunkOperations()}.
+ * Test method for {@link org.springframework.batch.execution.step.support.RepeatOperationsStep#getChunkOperations()}.
*/
public void testSetChunkOperations() {
@@ -62,7 +63,7 @@ public class RepeatOperationsStepTests extends TestCase {
}
/**
- * Test method for {@link org.springframework.batch.execution.step.simple.RepeatOperationsStep#getChunkOperations()}.
+ * Test method for {@link org.springframework.batch.execution.step.support.RepeatOperationsStep#getChunkOperations()}.
*/
public void testSetStepOperations() {